@@ -87,24 +87,28 @@ struct index_sizes_meta {
 	typedef typename string_meta< SPEC >::type                                                  string_t;              \
 	typedef typename seqan::Infix< string_t >::Type                                             infix_t;               \
 	typedef typename string_set_meta< SPEC >::type                                              string_set_t;          \
-	typedef boost::shared_ptr< string_set_t >                                                   string_set_ptr_t;      \
+	typedef boost::shared_ptr< string_set_t >                                                    string_set_ptr_t;      \
 	typedef typename id_set_meta< SPEC >::type                                                  id_set_t;              \
 	typedef typename index_tag_meta< SPEC >::type                                               index_tag_t;           \
 	typedef typename index_meta< SPEC >::type                                                   index_t;               \
-	typedef boost::shared_ptr< index_t >                                                        index_ptr_t;           \
-	typedef typename seqan::SAValue< index_t >::Type                                            sa_value_t;            \
+	typedef boost::shared_ptr< index_t >                                                         index_ptr_t;           \
 	typedef typename seqan::Fibre< index_t, seqan::EsaSA >::Type                                fibre_sa_t;            \
-	typedef typename seqan::Infix< fibre_sa_t const >::Type                                     occurrences_t;         \
+	typedef typename seqan::Infix< fibre_sa_t const >::Type                                    occurrences_t;         \
 	typedef typename seqan::Fibre< index_t, seqan::EsaText >::Type                              esa_text_fibre_t;      \
-	typedef typename seqan::Infix< esa_text_fibre_t const >::Type                               parent_edge_label_t;   \
+	typedef typename seqan::Infix< esa_text_fibre_t const >::Type                              parent_edge_label_t;   \
 	typedef typename seqan::Host< index_t >::Type                                               text_t;                \
-	typedef typename seqan::Id< text_t >::Type                                                  id_t;                  \
-	typedef boost::tuple< id_t, int >                                                           local_pos_t;           \
 	typedef typename seqan::Fibre< index_t, seqan::EsaRawText >::Type                           raw_text_t;            \
 	typedef typename seqan::StringSetLimits< text_t >::Type                                     string_set_limits_t;   \
-	typedef boost::shared_ptr< string_set_limits_t >                                            string_set_limits_ptr; \
+	typedef boost::shared_ptr< string_set_limits_t >                                             string_set_limits_ptr; \
+    typedef typename seqan::Id< text_t >::Type                                                  id_t;                  \
+    typedef typename seqan::Value< fibre_sa_t >::Type                                           sa_value_t;            \
+	typedef typename seqan::Value< sa_value_t, 1 >::Type                                        seq_index_t;           \
+	typedef typename seqan::Value< sa_value_t, 2 >::Type                                        seq_offset_t;          \
+    typedef boost::tuple< seq_index_t, seq_offset_t >                                            local_pos_t;           \
+    typedef typename seqan::Fibre< index_t, seqan::FibreChildtab >::Type                        child_tab_t;           \
+    typedef typename seqan::Value< child_tab_t >::Type                                          global_pos_t;          \
 	typedef typename seqan::Iterator< index_t, seqan::TopDown<> >::Type                         top_down_it;           \
-	typedef typename seqan::Infix< text_t const >::Type                                         representative_t;      \
+	typedef typename seqan::Infix< text_t const >::Type                                        representative_t;      \
 	typedef typename seqan::Prefix< representative_t >::Type                                    prefix_t;              \
     //typedef typename seqan::Iterator< index_t, seqan::TopDown< seqan::ParentLinks<> > >::Type   top_down_history_it;   \ //don't use this as it is very slow.
 
