@@ -14,17 +14,12 @@ from cookbook.named_tuple import namedtuple
 from scipy.special import gammaln, digamma
 import pyicl, numpy, pylab, os
 from collections import defaultdict
+from .scan import footprint
 
-
-
-
-SeqInfo = namedtuple('SeqInfo', 'name length')
-Occurrence = namedtuple('Occurrence', 'motif wmer seq pos strand Z score pvalue')
 PairOccurrence = namedtuple('PairOccurrence', 'spacing seq pos strand')
 Spacing = namedtuple('Spacing', 'primary secondary same_strand upstream distance')
 
 
-
 def add_max_distance_option(parser):
     parser.add_option(
         "-d",
@@ -34,53 +29,16 @@ def add_max_distance_option(parser):
         help="Only look for occurrences of motifs up to MAX_DISTANCE base pairs apart",
         metavar="MAX_DISTANCE"
     )
+
+
+def add_options(parser):
+    """Add options for spacing functionality to the parser.
+    """
+    from . import scan
+    scan.add_options(parser)
+    add_max_distance_option(parser)
     
 
-def footprint(occ):
-    """Return the footprint (interval) of the occurrence.
-    """
-    return pyicl.IntInterval(occ.pos, occ.pos + len(occ.wmer))
- 
-
-def parse_occurrence(line):
-    """Parse one occurrence in the format outputted by steme-pwm-scan.
-    """
-    fields = line.strip().split(',')
-    if 8 != len(fields):
-        raise RuntimeError('Wrong number of fields in line: %s' % line)
-    return Occurrence(
-        motif=fields[0],
-        wmer=fields[1],
-        seq=int(fields[2]),
-        pos=int(fields[3]),
-        strand=fields[4],
-        Z=float(fields[5]),
-        score=float(fields[6]),
-        pvalue=float(fields[7]),
-    )
-    
-def parse_occurrences(f):
-    """Parse lines of occurrences in the format outputted by steme-pwm-scan.
-    """
-    return map(parse_occurrence, f)
-
-def parse_seq_info(line):
-    """Parse one sequence info in the format outputted by steme-pwm-scan.
-    """
-    fields = line.strip().split(',')
-    if 2 != len(fields):
-        raise RuntimeError('Wrong number of fields in line: %s' % line)
-    return SeqInfo(
-        name=fields[1],
-        length=int(fields[0])
-    )
-    
-def parse_seq_infos(f):
-    """Parse lines of sequence infos in the format outputted by steme-pwm-scan.
-    """
-    return map(parse_seq_info, f)
-
-
 def spacing_idx(max_distance, distance, upstream, same_strand):
     """Calculates an index into a spacing array.
     
@@ -208,32 +166,7 @@ def calc_llr_statistic(obs, alpha):
 
 
 
-def ticks_restrict_to_integer(axis):
-    """Restrict the ticks on the given axis to be at least integer,
-    that is no half ticks at 1.5 for example.
-    """
-    from matplotlib.ticker import MultipleLocator
-    major_tick_locs = axis.get_majorticklocs()
-    if len(major_tick_locs) < 2 or major_tick_locs[1] - major_tick_locs[0] < 1:
-        axis.set_major_locator(MultipleLocator(1))
-    
 
-def _test_restrict_to_integer():
-    pylab.figure()
-    ax = pylab.subplot(1, 2, 1)
-    pylab.bar(range(1,4), range(1,4), align='center')
-    ticks_restrict_to_integer(ax.xaxis)
-    ticks_restrict_to_integer(ax.yaxis)
-    
-    ax = pylab.subplot(1, 2, 2)
-    pylab.bar(range(1,4), range(100,400,100), align='center')
-    ticks_restrict_to_integer(ax.xaxis)
-    ticks_restrict_to_integer(ax.yaxis)
-
-#_test_restrict_to_integer()
-#pylab.show()
-
-    
 def plot_spacings(max_distance, spacing_counts):
     """Plot the spacing counts in four subplots.
     """
@@ -406,66 +339,6 @@ def log_spacings(spacings):
             logger.info(spacing_str(spacing))
 
 
-def add_options(parser):
-    """Add options for spacing functionality to the parser.
-    """
-    parser.add_option(
-        "-r",
-        "--results-dir",
-        default='.',
-        help="Look for results from PWM scan in directory: DIR",
-        metavar="DIR"
-    )
-    parser.add_option(
-        "-d",
-        "--max-distance",
-        type=int,
-        default=30,
-        help="Only look for occurrences of motifs up to MAX_DISTANCE base pairs apart",
-        metavar="MAX_DISTANCE"
-    )
-    
-    
-def load_occurrences(options):
-    """Load the occurrences and associated sequence lengths.
-    """
-    occurrences_filename = os.path.join(options.results_dir, 'steme-pwm-scan.out')
-    seqs_filename = os.path.join(options.results_dir, 'steme-pwm-scan.seqs')
-    logger.info('Reading occurrences from: %s and sequence information from: %s', occurrences_filename, seqs_filename)
-    return load_occurrences_from_stream(open(occurrences_filename), open(seqs_filename))
-    
-    
-    
-def load_occurrences_from_stream(occurrences_stream, seqs_stream):
-    """Load the occurrences and associated sequence lengths.
-    """
-    #
-    # Read in the occurrences
-    #
-    occurrences = parse_occurrences(occurrences_stream)
-    
-    
-    #
-    # Read in the sequence lengths
-    #
-    seq_infos = parse_seq_infos(seqs_stream)
-    
-    
-    #
-    # Gather all the motifs
-    #
-    motifs = set(occ.motif for occ in occurrences)
-    
-    
-    #
-    # Sort the occurrences by position
-    #
-    logger.info('Sorting %d occurrences', len(occurrences))
-    occurrences.sort(key=lambda x: (x.seq, x.pos))
-    
-    return occurrences, seq_infos, motifs
-
-
 def load_spacings(spacings_filename, motifs, options):
     """Load spacings from filename. Check they are consistent with motif list.
     """
